@@ -17,30 +17,30 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void create_circle_with_radius(void);
+void create_circle_with_radius(_param p);
 
-void circle_center(void);
+void circle_center(_param p);
 
-void create_circle_with_diameter(void);
+void create_circle_with_diameter(_param p);
 
-void create_circumcircle(void);
+void create_circumcircle(_param p);
 
-void create_incircle(void);
+void create_incircle(_param p);
 
-void translate_circle(void);
+void translate_circle(_param p);
 
-void reflect_circle(void);
+void reflect_circle(_param p);
 
-void symetric_circle(void);
+void symetric_circle(_param p);
 
-void rotate_circle(void);
+void rotate_circle(_param p);
 
-void homothetic_circle(void);
+void homothetic_circle(_param p);
 
-void circle_radius(void);
+void circle_radius(_param p);
 
-void circle_perimeter(void);
+void circle_perimeter(_param p);
 
-void circle_area(void);
+void circle_area(_param p);
 
-void point_on_circle_argument(void);
+void point_on_circle_argument(_param p);
