@@ -17,6 +17,9 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifndef CORE_H
+#define CORE_H
+
 typedef union {
     void *ptr;
     double num;
@@ -41,7 +44,7 @@ typedef struct {
     const char* inst;
     int arg;
 #endif
-    void (*func)();
+    void (*func)(_param param);
     _param param;
 } _instr;
 
@@ -58,19 +61,19 @@ void goto_addr(_param p);
 
 void gosub_addr(_param p);
 
-void go_back(void);
+void go_back(_param p);
 
 void jump_if_zero(_param p);
 
-void stop(void);
+void stop(_param p);
 
 void set_cur_line(_param p);
 
 void set_cur_file(_param p);
 
-void exec_itable(void);
+void exec_itable(_param p);
 
-void reset_stack_machine(void);
+void reset_stack_machine(_param p);
 
 void *allocate(int size);
 
@@ -79,3 +82,4 @@ void *allocate(int size);
 #define get_elem(var) \
         var = (_set *)allocate(sizeof(_set)); \
         var->p = (_point *)allocate(sizeof(_point))
+#endif
