@@ -19,40 +19,40 @@
 
 int preamble;
 
-void put_preamble(void);
+void put_preamble(_param p);
 
-void put_closing(void);
+void put_closing(_param p);
 
-void draw_point(void);
+void draw_point(_param p);
 
-void draw_vector(void);
+void draw_vector(_param p);
 
-void draw_path(void);
+void draw_path(_param p);
 
-void draw_polygon(void);
+void draw_polygon(_param p);
 
-void fill_polygon(void);
+void fill_polygon(_param p);
 
-void hatch_polygon(void);
+void hatch_polygon(_param p);
 
-void draw_line(void);
+void draw_line(_param p);
 
-void draw_circle(void);
+void draw_circle(_param p);
 
-void draw_arc(void);
+void draw_arc(_param p);
 
-void fill_circle(void);
+void fill_circle(_param p);
 
-void hatch_circle(void);
+void hatch_circle(_param p);
 
-void draw_conic(void);
+void draw_conic(_param p);
 
-void draw_conic_arc(void);
+void draw_conic_arc(_param p);
 
 void draw_string(_param p);
 
-void label_segment(void);
+void label_segment(_param p);
 
-void label_angle(void);
+void label_angle(_param p);
 
 void label_point(_param p);
