@@ -88,7 +88,7 @@ void restore_table(_function func)
 	drop((_param)(void *)*sym);
 }
 
-void return_error(void)
+void return_error(_param p)
 {
     runtime_error(_("function ending without return statement"));
 }
