@@ -29,7 +29,7 @@ void check_return(int type);
 
 void end_function(void);
 
-void restore_variables(void);
+void restore_variables(_param p);
 
 void init_call(_symbol *symbol);
 
