@@ -17,20 +17,20 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void orthogonal_projection(void);
+void orthogonal_projection(_param p);
 
-void parallel_projection(void);
+void parallel_projection(_param p);
 
-void lines_intersection(void);
+void lines_intersection(_param p);
 
-void line_set_intersection(void);
+void line_set_intersection(_param p);
 
-void line_circle_intersection(void);
+void line_circle_intersection(_param p);
 
-void line_conic_intersection(void);
+void line_conic_intersection(_param p);
 
-void sets_intersection(void);
+void sets_intersection(_param p);
 
-void circles_intersection(void);
+void circles_intersection(_param p);
 
-void circle_set_intersection(void);
+void circle_set_intersection(_param p);
