@@ -19,26 +19,26 @@
 
 extern int output;
 
-void open_read_mode(void);
+void open_read_mode(_param p);
 
-void open_write_mode(void);
+void open_write_mode(_param p);
 
-void open_append_mode(void);
+void open_append_mode(_param p);
 
-void close_data_file(void);
+void close_data_file(_param p);
 
-void close_result_file(void);
+void close_result_file(_param p);
 
-void print_num(void);
+void print_num(_param p);
 
-void print_pnt(void);
+void print_pnt(_param p);
 
-void print_set(void);
+void print_set(_param p);
 
-void print_str(void);
+void print_str(_param p);
 
-void print_nl(void);
+void print_nl(_param p);
 
-void input_num(void);
+void input_num(_param p);
 
-void input_str(void);
+void input_str(_param p);
