@@ -21,4 +21,4 @@ extern int locus_addr;
 
 void init_locus(_param p);
 
-void put_pnt(void);
+void put_pnt(_param p);
