@@ -17,54 +17,54 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void add(void);
+void add(_param p);
 
-void substract(void);
+void substract(_param p);
 
-void multiply(void);
+void multiply(_param p);
 
-void divide(void);
+void divide(_param p);
 
-void modulo(void);
+void modulo(_param p);
 
-void change_sign(void);
+void change_sign(_param p);
 
-void square_root(void);
+void square_root(_param p);
 
-void power(void);
+void power(_param p);
 
-void exponential(void);
+void exponential(_param p);
 
-void logarithm(void);
+void logarithm(_param p);
 
-void rtod(void);
+void rtod(_param p);
 
-void dtor(void);
+void dtor(_param p);
 
-void sine(void);
+void sine(_param p);
 
-void cosine(void);
+void cosine(_param p);
 
-void tangent(void);
+void tangent(_param p);
 
-void arcsine(void);
+void arcsine(_param p);
 
-void arccosine(void);
+void arccosine(_param p);
 
-void arctangent(void);
+void arctangent(_param p);
 
-void absolute_value(void);
+void absolute_value(_param p);
 
-void sign(void);
+void sign(_param p);
 
-void ceil_value(void);
+void ceil_value(_param p);
 
-void floor_value(void);
+void floor_value(_param p);
 
-void round_value(void);
+void round_value(_param p);
 
-void minimum(void);
+void minimum(_param p);
 
-void maximum(void);
+void maximum(_param p);
 
-void clamp(void);
+void clamp(_param p);
