@@ -17,42 +17,42 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void create_point_cartesian(void);
+void create_point_cartesian(_param p);
 
-void create_point_polar(void);
+void create_point_polar(_param p);
 
-void create_point_on_segment(void);
+void create_point_on_segment(_param p);
 
-void create_point_on_line(void);
+void create_point_on_line(_param p);
 
-void create_point_with_abscissa(void);
+void create_point_with_abscissa(_param p);
 
-void create_point_with_ordinate(void);
+void create_point_with_ordinate(_param p);
 
-void create_point_on_circle(void);
+void create_point_on_circle(_param p);
 
-void create_point_on_conic(void);
+void create_point_on_conic(_param p);
 
-void create_midpoint(void);
+void create_midpoint(_param p);
 
-void create_isobarycenter(void);
+void create_isobarycenter(_param p);
 
-void create_barycenter(void);
+void create_barycenter(_param p);
 
-void create_orthocenter(void);
+void create_orthocenter(_param p);
 
-void translate_point(void);
+void translate_point(_param p);
 
-void reflect_point(void);
+void reflect_point(_param p);
 
-void symetric_point(void);
+void symetric_point(_param p);
 
-void rotate_point(void);
+void rotate_point(_param p);
 
-void homothetic_point(void);
+void homothetic_point(_param p);
 
-void point_abscissa(void);
+void point_abscissa(_param p);
 
-void point_ordinate(void);
+void point_ordinate(_param p);
 
-void points_distance(void);
+void points_distance(_param p);
