@@ -17,44 +17,44 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void create_set(void);
+void create_set(_param p);
 
-void create_segment(void);
+void create_segment(_param p);
 
-void add_head_point(void);
+void add_head_point(_param p);
 
-void add_tail_point(void);
+void add_tail_point(_param p);
 
-void catenate_sets(void);
+void catenate_sets(_param p);
 
-void push_point(void);
+void push_point(_param p);
 
 void extract_point(_param p);
 
 void extract_subset(_param p);
 
-void create_polygon(void);
+void create_polygon(_param p);
 
-void translate_set(void);
+void translate_set(_param p);
 
-void reflect_set(void);
+void reflect_set(_param p);
 
-void symetric_set(void);
+void symetric_set(_param p);
 
-void rotate_set(void);
+void rotate_set(_param p);
 
-void homothetic_set(void);
+void homothetic_set(_param p);
 
-void set_cardinal(void);
+void set_cardinal(_param p);
 
 void path_length(_param p);
 
-void polygon_area(void);
+void polygon_area(_param p);
 
-void create_centroid(void);
+void create_centroid(_param p);
 
-void segment_argument(void);
+void segment_argument(_param p);
 
-void vertex_angle(void);
+void vertex_angle(_param p);
 
-void triangle_height(void);
+void triangle_height(_param p);
