@@ -255,7 +255,7 @@ void restore_default_settings(void)
     global_dec = local_dec = NONE;
 }
 
-void restore_global_settings(void)
+void restore_global_settings(_param p)
 {
     local_style = global_style;
     local_shape = global_shape;
