@@ -17,9 +17,11 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void init_string(void);
+#include "core.h"
 
-void start_buffer(void);
+void init_string(_param p);
+
+void start_buffer(_param p);
 
 void add_string(char *s, int l);
 
@@ -27,26 +29,26 @@ void add_char(char ch);
 
 void add_special_char(char ch);
 
-char *get_buffer(void);
+char *get_buffer(_param p);
 
-void extract_substring(void);
+void extract_substring(_param p);
 
-void start_string(void);
+void start_string(_param p);
 
-void cat_num(void);
+void cat_num(_param p);
 
-void cat_pnt(void);
+void cat_pnt(_param p);
 
-void cat_set(void);
+void cat_set(_param p);
 
-void cat_str(void);
+void cat_str(_param p);
 
-void get_string(void);
+void get_string(_param p);
 
-void str_eq(void);
+void str_eq(_param p);
 
-void str_neq(void);
+void str_neq(_param p);
 
-void str_length(void);
+void str_length(_param p);
 
 char* get_output_name(char* in, const char* suf);
