@@ -17,36 +17,36 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void create_vector_cartesian(void);
+void create_vector_cartesian(_param p);
 
-void create_vector_polar(void);
+void create_vector_polar(_param p);
 
-void create_vector_from_points(void);
+void create_vector_from_points(_param p);
 
-void create_vector_from_segment(void);
+void create_vector_from_segment(_param p);
 
-void create_vector_from_line(void);
+void create_vector_from_line(_param p);
 
-void add_vectors(void);
+void add_vectors(_param p);
 
-void substract_vectors(void);
+void substract_vectors(_param p);
 
-void reverse_vector(void);
+void reverse_vector(_param p);
 
-void multiply_vector(void);
+void multiply_vector(_param p);
 
-void divide_vector(void);
+void divide_vector(_param p);
 
-void rotate_vector(void);
+void rotate_vector(_param p);
 
-void vector_abscissa(void);
+void vector_abscissa(_param p);
 
-void vector_ordinate(void);
+void vector_ordinate(_param p);
 
-void vector_length(void);
+void vector_length(_param p);
 
-void vector_argument(void);
+void vector_argument(_param p);
 
-void vectors_angle(void);
+void vectors_angle(_param p);
 
-void scalar_product(void);
+void scalar_product(_param p);
