@@ -37,15 +37,15 @@ int main(int argc, char *argv[])
     process_args(argc, argv);
     load_keywords();
     init_symbol_list();
-    init_string();
+    init_string((_param)0);
     init_module_stack();
     init_stack_machine();
     yyparse();
     if (anim_amount)
 	for (anim_cur = 0; anim_cur < anim_amount; anim_cur++) {
-	    exec_itable();
+	  exec_itable((_param)0);
 	    strokes[anim_state][anim_dir] += anim_inc;
 	}
-    else exec_itable();
+    else exec_itable((_param)0);
     return EXIT_SUCCESS;
 }
