@@ -17,26 +17,26 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void check_color(void);
+void check_color(_param p);
 
-void check_shape(void);
+void check_shape(_param p);
 
-void check_dotsize(void);
+void check_dotsize(_param p);
 
-void check_style(void);
+void check_style(_param p);
 
-void check_font(void);
+void check_font(_param p);
 
-void check_linewidth(void);
+void check_linewidth(_param p);
 
-void check_arrowsize(void);
+void check_arrowsize(_param p);
 
 void check_hatch(double a);
 
-void check_path_settings(void);
+void check_path_settings(_param p);
 
-void put_local(void);
+void put_local(_param p);
 
-void put_font(void);
+void put_font(_param p);
 
-void put_egroup(void);
+void put_egroup(_param p);
