@@ -37,10 +37,10 @@ int main(int argc, char *argv[])
     process_args(argc, argv);
     load_keywords();
     init_symbol_list();
-    init_string();
+    init_string((_param)0);
     init_module_stack();
     init_stack_machine();
     yyparse();
-    exec_itable();
+    exec_itable((_param)0);
     return EXIT_SUCCESS;
 }
